#
# spec file for package sonic-visualiser
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2016 Tom Mbrt <tom.mbrt@googlemail.com>
# Copyright (c) 2005-2010 oc2pus
# Copyright (c) 2011 Evstifeev Roman <someuniquename@gmail.com>
# Copyright (c) 2012 Pascal Bleser <pascal.bleser@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

%bcond_with mad
Name:           sonic-visualiser
Version:        2.5
Release:        1.1
Summary:        A program for viewing and analysing contents of audio files
License:        GPL-2.0+
Group:          Productivity/Multimedia/Sound/Utilities
Url:            http://www.sonicvisualiser.org/
Source:         https://code.soundsoftware.ac.uk/attachments/download/1675/%{name}-%{version}.tar.gz
Source1:        %{name}.desktop
Source2:        %{name}.xml
Patch0:         sonic-visualiser-ld-X11-fix.patch
Patch1:         sonic-visualiser-remove-svcore-test.patch
BuildRequires:  alsa-devel
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  curl-devel
BuildRequires:  dssi
BuildRequires:  fftw3-devel
BuildRequires:  flac
BuildRequires:  flac-devel
BuildRequires:  freetype2-devel
BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
BuildRequires:  ladspa
BuildRequires:  libbz2-devel
BuildRequires:  libid3tag-devel
BuildRequires:  libjack-devel
BuildRequires:  libjpeg8-devel
BuildRequires:  liblo-devel
BuildRequires:  liblrdf-devel
BuildRequires:  libogg-devel
BuildRequires:  liboggz-devel >= 0.9.5
BuildRequires:  libpng-devel
BuildRequires:  libpulse-devel
BuildRequires:  libqt5-qtbase-devel >= 5.2
BuildRequires:  libraptor-devel >= 2.0.4
BuildRequires:  librasqal-devel
BuildRequires:  libredland-devel >= 1.0.14
BuildRequires:  librubberband-devel
BuildRequires:  libsamplerate-devel
BuildRequires:  libserd-0-devel
BuildRequires:  libsndfile-devel
BuildRequires:  libsord-0-devel
BuildRequires:  libspeex-devel
BuildRequires:  libvorbis-devel
BuildRequires:  libxslt-devel
BuildRequires:  pkgconfig
BuildRequires:  portaudio-devel
BuildRequires:  shared-mime-info
BuildRequires:  update-desktop-files
BuildRequires:  vamp-plugin-sdk-devel >= 2.5
BuildRequires:  xorg-x11-devel
BuildRequires:  zlib-devel
%if 0%{?BUILD_ORIG}
BuildRequires:  libdataquay-devel >= 0.9
%endif
%if %{with mad}
BuildRequires:  libmad-devel
%endif
Requires:       dssi
Requires:       ladspa

%description
Sonic Visualiser is a program for viewing and analysing the contents
of music audio files.

With Sonic Visualiser you can:
* Load audio files in various formats and view their waveforms

* Look at audio visualisations such as spectrogram views, with
  interactive adjustment of display parameters

* Annotate audio data by adding labelled time points and defining
  segments, point values and curves

* Run feature-extraction plugins to calculate annotations
  automatically, using algorithms such as beat trackers, pitch
  detectors and so on

* Import annotation data from various text formats and MIDI files

* Play back the original audio with synthesised annotations, taking
  care to synchronise playback with the display position

* Slow down playback and loop segments of interest, including
  seamless looping of complex non-contiguous areas

* Export annotations and audio selections to external files.

* Sonic Visualiser can also be controlled remotely using the Open Sound
  Control (OSC) protocol

%prep
%setup -q
%patch0
%patch1

%build
export dataquay_CFLAGS='-I/usr/include/dataquay'
export dataquay_LIBS='-ldataquay -lrdf'

export CFLAGS="%{optflags}" CXXFLAGS="%{optflags}"
sh bootstrap.sh
%configure
make %{?_smp_mflags}


%install

install -dm 755 %{buildroot}%{_bindir}
install -m 755 sonic-visualiser %{buildroot}%{_bindir}

# plugin dir
install -dm 755 %{buildroot}%{_libdir}/vamp

# icon
for size in 16 22 24 32 48 64 128 ; do
install -Dm 644 icons/sv-${size}x${size}.png %{buildroot}/%{_datadir}/icons/hicolor/${size}x${size}/apps/%{name}.png
done

install -Dm 644 icons/sv-icon.svg %{buildroot}/%{_datadir}/icons/hicolor/scalable/apps/%{name}.svg
ln -s sonic-visualiser.svg %{buildroot}/%{_datadir}/icons/hicolor/scalable/apps/sv-icon.svg

# mime types
install -Dm 644 %{SOURCE2} %{buildroot}%{_datadir}/mime/packages/%{name}.xml
install -Dm 644 x-sonicvisualiser.desktop %{buildroot}/%{_datadir}/mimelnk/application/x-sonicvisualiser.desktop
install -Dm 644 x-sonicvisualiser-layer.desktop %{buildroot}/%{_datadir}/mimelnk/application/x-sonicvisualiser-layer.desktop

# Menu
install -Dm 644 %{SOURCE1} %{buildroot}%{_datadir}/applications/%{name}.desktop
%suse_update_desktop_file -i %{name} AudioVideo Audio Music

%post
%desktop_database_post
%icon_theme_cache_post
%{_bindir}/update-mime-database %{_datadir}/mime &> /dev/null || :

%postun
%desktop_database_postun
%icon_theme_cache_postun
%{_bindir}/update-mime-database %{_datadir}/mime &> /dev/null || :

%files
%defattr(-,root,root)
%doc COPYING README*
%{_bindir}/%{name}
%dir %{_libdir}/vamp
%{_datadir}/icons/hicolor/*/apps/%{name}.*
%{_datadir}/icons/hicolor/scalable/apps/sv-icon.svg
%{_datadir}/applications/%{name}.desktop
%{_datadir}/mime/packages/%{name}.xml
%dir %{_datadir}/mimelnk
%dir %{_datadir}/mimelnk/application
%{_datadir}/mimelnk/application/x-sonicvisualiser*

%changelog
* Sat Jan  7 2017 aloisio@gmx.com
- Update to version 2.5
  * Add unit-converter dialog, for converting between various
    pitch and timing units
  * Fix failure to reload note layers from session file
  * Use a more sensible scale for the play-speed dial
  * Fix crash when importing very wide CSV files
  * Fix generation of wrong layer type from some CSV files
  * Fix failure to export last instant in a time-instant layer
  version 2.4:
  * Fix a crash when rendering certain colour 3d plot layers
  version 2.3:
  * Add support for left/right scrolling using a two-finger
    touchpad gesture (where available)
  * Make the octave numbering into a configurable option, and
    change the default. Previously Sonic Visualiser labelled
    middle-C as "C3"; now it labels middle-C as "C4", a more
    common standard in the world outside MIDI sequencer
    software. The previous system is available as an option
    in the Preferences. This affects only the visible
    labels: there is no change to analysis or to the file
    format
  * Sonify time-value layers. Any time-value curve whose scale
    unit is set to Hz will now acquire a playback toggle
    control; this control is off by default, but if it is
    switched on, the curve will be played back using a
    variable-frequency sound generator
  * Add support for playback of note layers with non-MIDI
    frequencies (formerly the note playback was limited to
    exact MIDI pitch)
  * Change the default playback sample for note layers from
    piano to an electric piano with sustain. The piano sample
    is still available, and any sessions saved using it should
    continue to use it
  * Add a cancel button for Vamp plugin processing: currently,
    cancelling a transform results in a part-complete layer
    rather than removing the results
  * Add keyboard shortcuts to cycle the current layer (in
    addition to the existing ones to cycle the current pane)
  * Fix various bugs related to layer ordering: layer tabs
    re-ordering themselves randomly when new layer added,
    layers being ordered randomly when saving and reloading
    a session
  * Fix incorrect interaction with non-Unicode usernames when
    creating temporary and template directories on Windows
  * Shade the start and end of the main audio file, to make
    them easier to see for files that start or end in silence
  * Speed up rendering and scrolling in time-value layers
  * Make it possible to import CSV files directly into Note
    layers by adding Pitch as a data type in the CSV file
    import dialog
  * Fix play pointer jump to wrong frame when clicking on row
    in the layer edit dialog
  * Fix problems with keyboard shortcuts when using Qt5 on
    OS/X. This is the first release in which the official
    builds use Qt5 for all platforms.
  version 2.2:
  * Add a startup welcome dialog that also explains what SV
    makes network connections for and allows user to forbid
    them
  * Add "Export Audio Data" feature
  * Show piano keyboard scale in note and time-value layers as
    well as spectrogram, where vertical scale is log Hz; also
    show numerical scale in note and region layers when not
    auto-aligned
  * Speed up CSV file import and avoid showing crazily wide
    window for CSV file format dialog when file has lots of
    columns
  * Fix incorrectly saved window geometry when exiting from
    maximised state
  * Reduce number of timer wakeups when idle
  * Add American English translation and make choice of
    translation into a preference (defaulting to system locale)
  * Permit installation to non-default location with Windows
    installer build
  version 2.1:
  * Build with support for hidpi ("retina") text on OS/X
  * Fix very slow analysis when using Ogg or FLAC files decoded
    via libsndfile
  * Fix inaccurate scale auto-align between time-value layers
    and others
  * Fix failure to open files specified on command line (or via
    Open With) on Windows
  * Reset cyclical counters and switch back to navigate mode
    when a new session is started
  version 2.0.1:
  * Fix incorrect handling of FixedSampleRate outputs (Vamp
    SDK fix)
  * Make it easier to see results from transforms that return
    a single point
  * Make labelling clearer on time-value layers
  * Add discrete-curve mode for time-value layers (for curves
    with gaps)
  * Update code to build against Qt5
  version  2.0:
  * Fix incorrect samplerate in reading m4a files on OS/X
  version 1.9:
  * Support 64-bit builds on OS/X (using CoreAudio instead of
    obsolete QuickTime audio file reader)
  * Simplify RDF reading and fix some bugs. Now requires
    Dataquay (http://breakfastquay.com/dataquay/) rather than
    using Redland directly. Release builds use Sord/Serd rather
    than Redland
  * Add a fullscreen mode on the F11 key
- Refreshed sonic-visualiser-ld-X11-fix.patch
- Removed gcc-4.7.patch
- Added sonic-visualiser-remove-svcore-test.patch
  sonic-visualiser.desktop and sonic-visualiser.xml
- Spec cleanup
* Mon Oct  6 2014 avvissu@yandex.ru
- Patch to fix build (gcc-4.7.patch)
* Wed Mar 14 2012 pascal.bleser@opensuse.org
- add bits to enable mp3 support with mad when built on Packman
* Wed Mar 14 2012 pascal.bleser@opensuse.org
- remove dependency on licenses, gone in 12.1
- reformat spec file, fix license tag to be compliant with SPDX
* Thu Oct 20 2011 someuniquename@gmail.com
- update to 1.9
* Wed May  5 2010 toni@links2linux.de
- update to 1.7.2
* Thu Oct 29 2009 toni@links2linux.de
- update to 1.7.1
- This release contains a small number of enhancements and bug fixes.
  For more information, please read the change log at:
  https://sourceforge.net/projects/sv1/files/sonic-visualiser/1.7.1/CHANGELOG/download
* Mon Oct 26 2009 toni@links2linux.de
- update to 1.7
- The main focus of this release is to improve editing of note and region layers.
  It can import MIDI files that use SMPTE timecode for event timing, and
  optionally display time in seconds and frames at various frame rates throughout.
  A crash on exit in Windows has been fixed, and a number of other bugfixes are
  included.
* Mon Mar 16 2009 toni@links2linux.de
- update to 1.5
* Thu Dec 11 2008 toni@links2linux.de
- update to 1.4
* Thu Jul 10 2008 toni@links2linux.de
- update to 1.3
- using new rubberband-1.2
- added PulseAudio output driver
* Sun Mar 23 2008 toni@links2linux.de
- rebuild with new vamp-plugin-sdk
* Wed Feb 20 2008 toni@links2linux.de
- update to 1.2
* Mon Dec 31 2007 toni@links2linux.de
- rebuild with new libraptor/vamp-sdk packages
* Sun Sep  9 2007 toni@links2linux.de
- openSUSE-10.3 build corrected BuildRequires
* Tue Jun  5 2007 toni@links2linux.de
- rebuild with libfishsound1 (0.8.0)
* Fri May 11 2007 toni@links2linux.de
- update to 1.0
* Tue Mar 20 2007 toni@links2linux.de
- update to 1.0pre3
- moved all vamp-plugins to seperate packages
- using vamp-plugin-sdk to build
- switched to portaudio-19
* Mon Jan  1 2007 toni@links2linux.de
- build SuSE-10.2, corrected BuildRequires
* Thu Sep 21 2006 toni@links2linux.de
- build for packman
* Sat May 27 2006 oc2pus@arcor.de 0.9-0.oc2pus.2
- rebuild for SuSE-10.1 (no dssi-devel)
* Sun May 21 2006 oc2pus@arcor.de 0.9-0.oc2pus.1
- Initial release 0.9
- added vamp-QM-plugin 1.0
- added vamp-aubio-plugin 0.3.0
- added vamp-mazurka-plugins
  download sources from http://sv.mazurka.org.uk and packaged as tar.bz2,
  added libmain.cpp and create a shared lib with allmazurka-plugins
